@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 """API models package."""
-from . import adapters, assets, enforcements, entry, mixins, parsers, routers, system
+from . import adapters, assets, enforcements, mixins, parsers, routers, signup, system
 from .adapters import Adapters
 from .assets import Devices, Users
 from .enforcements import Enforcements, RunAction
-from .entry import Entry
-from .system import System
+from .signup import Signup
+from .system import Dashboard, Instances, System, dashboard, instances
 
 __all__ = (
     "Users",
@@ -14,7 +14,9 @@ __all__ = (
     "Enforcements",
     "RunAction",
     "System",
-    "Entry",
+    "Instances",
+    "Dashboard",
+    "Signup",
     "routers",
     "assets",
     "adapters",
@@ -22,5 +24,7 @@ __all__ = (
     "mixins",
     "system",
     "parsers",
-    "entry",
+    "signup",
+    "instances",
+    "dashboard",
 )
