@@ -10,20 +10,39 @@ from .asset_mixin import AssetMixin
 class Devices(AssetMixin):
     """Device related API methods."""
 
+    FIELD_ASSET_NAME: str = "specific_data.data.name"
     FIELD_HOSTNAME: str = "specific_data.data.hostname"
     FIELD_IP: str = "specific_data.data.network_interfaces.ips"
     FIELD_IP_RAW: str = "specific_data.data.network_interfaces.ips_raw"
     FIELD_MAC: str = "specific_data.data.network_interfaces.mac"
     FIELD_SUBNET: str = "specific_data.data.network_interfaces.subnets"
+    FIELD_OS_TYPE: str = "specific_data.data.os.type"
+    FIELD_MAIN: str = FIELD_HOSTNAME
+    FIELD_SIMPLE: str = FIELD_HOSTNAME
+    FIELD_COMPLEX: str = "specific_data.data.network_interfaces"
+    FIELD_COMPLEX_SUB: str = "name"
+
+    FIELDS_SPECIFIC: List[str] = [
+        FIELD_ASSET_NAME,
+        FIELD_HOSTNAME,
+        FIELD_IP,
+        FIELD_MAC,
+        FIELD_SUBNET,
+        FIELD_OS_TYPE,
+    ]
 
     @property
     def fields_default(self) -> List[str]:
         """Fields to use by default for getting assets."""
-        return self.FIELDS_API + [
+        return [
+            self.FIELD_ADAPTERS,
+            self.FIELD_ASSET_NAME,
             self.FIELD_HOSTNAME,
+            self.FIELD_LAST_SEEN,
             self.FIELD_IP,
             self.FIELD_MAC,
-            self.FIELD_SUBNET,
+            self.FIELD_OS_TYPE,
+            self.FIELD_TAGS,
         ]
 
     @property
@@ -76,9 +95,7 @@ class Devices(AssetMixin):
         kwargs["value"] = value
         return self.get_by_value_regex(**kwargs)
 
-    def get_by_mac(
-        self, value: str, **kwargs
-    ) -> Union[Generator[dict, None, None], List[dict]]:
+    def get_by_mac(self, value: str, **kwargs) -> Union[Generator[dict, None, None], List[dict]]:
         """Build a query to get assets where mac == value."""
         kwargs["field"] = self.FIELD_MAC
         kwargs["field_manual"] = True
@@ -103,9 +120,7 @@ class Devices(AssetMixin):
         kwargs["value"] = value
         return self.get_by_value_regex(**kwargs)
 
-    def get_by_ip(
-        self, value: str, **kwargs
-    ) -> Union[Generator[dict, None, None], List[dict]]:
+    def get_by_ip(self, value: str, **kwargs) -> Union[Generator[dict, None, None], List[dict]]:
         """Build a query to get assets where ip == value."""
         kwargs["field"] = self.FIELD_IP
         kwargs["field_manual"] = True
@@ -139,7 +154,10 @@ class Devices(AssetMixin):
         inner = f"{field} == {match}"
 
         kwargs["query"] = self._build_query(
-            inner=inner, pre=pre, post=post, not_flag=not_flag,
+            inner=inner,
+            pre=pre,
+            post=post,
+            not_flag=not_flag,
         )
 
         return self.get(**kwargs)
