@@ -12,7 +12,7 @@ class CentralCore(ChildMixins):
         """Get the current central core configuration."""
         return self._get()
 
-    def update(self, enabled: bool, delete_backups: bool) -> dict:
+    def update(self, enabled: bool, delete_backups: bool) -> dict:  # pragma: no cover
         """Update the current central core configuration."""
         return self._update(enabled=enabled, delete_backups=delete_backups)
 
@@ -25,7 +25,7 @@ class CentralCore(ChildMixins):
         preshared_key: Optional[str] = None,
         allow_re_restore: bool = False,
         delete_backups: bool = False,
-    ) -> dict:
+    ) -> dict:  # pragma: no cover
         """Perform a restore from a file object in an AWS S3 Bucket."""
         restore_opts = {}
         restore_opts["key_name"] = key_name
@@ -54,21 +54,19 @@ class CentralCore(ChildMixins):
         response = self.request(method="get", path=path)
         return response
 
-    def _update(self, enabled: bool, delete_backups: bool) -> dict:
+    def _update(self, enabled: bool, delete_backups: bool) -> dict:  # pragma: no cover
         """Set the current central core configuration."""
         data = {"enabled": enabled, "delete_backups": delete_backups}
         path = self.router.central_core
         response = self.request(method="post", path=path, json=data)
         return response
 
-    def _restore(self, restore_type: str, restore_opts: dict) -> dict:
+    def _restore(self, restore_type: str, restore_opts: dict) -> dict:  # pragma: no cover
         """Perform a central core restore operation."""
         data = {}
         data["restore_type"] = restore_type
         data.update(restore_opts)
 
         path = self.router.central_core_restore
-        response = self.request(
-            method="post", path=path, json=data, response_timeout=3600
-        )
+        response = self.request(method="post", path=path, json=data, response_timeout=3600)
         return response
