@@ -3,8 +3,14 @@
 import click
 
 from ..context import AliasedGroup
-from . import (cmd_config_get, cmd_config_update, cmd_config_update_from_json,
-               cmd_file_upload, cmd_get, grp_cnx)
+from . import (
+    cmd_config_get,
+    cmd_config_update,
+    cmd_config_update_from_json,
+    cmd_file_upload,
+    cmd_get,
+    grp_cnx,
+)
 
 
 @click.group(cls=AliasedGroup)
