@@ -6,12 +6,7 @@ import warnings
 import pytest
 
 from axonius_api_client.constants import CSV_ADAPTER, DEFAULT_NODE
-from axonius_api_client.exceptions import (
-    ApiError,
-    ConfigUnchanged,
-    ConfigUnknown,
-    NotFoundError,
-)
+from axonius_api_client.exceptions import ApiError, ConfigUnchanged, ConfigUnknown, NotFoundError
 
 from ...meta import (
     CSV_FILECONTENT_BYTES,
@@ -24,7 +19,6 @@ from ...meta import (
 
 
 def val_parsed_schema(schema):
-    """Pass."""
     for setting_name, item in schema.items():
         item_name = item.pop("name")
         assert isinstance(item_name, str) and item_name
@@ -55,7 +49,10 @@ def val_parsed_schema(schema):
                 assert isinstance(x["name"], str)
                 assert isinstance(x["title"], str)
                 continue
-            assert isinstance(x, str) and x
+            if item_type == "integer":
+                assert isinstance(x, int)
+            else:
+                assert isinstance(x, str) and x
 
         item_default = item.pop("default", "")
         assert isinstance(item_default, (str, int, bool)) or item_default in [
@@ -81,30 +78,22 @@ def val_parsed_schema(schema):
 
 
 class TestAdaptersBase:
-    """Pass."""
-
     @pytest.fixture(scope="class")
     def apiobj(self, api_adapters):
-        """Pass."""
         return api_adapters
 
     @pytest.fixture(scope="class")
     def adapter(self, apiobj):
-        """Pass."""
         return apiobj.get_by_name(name=CSV_ADAPTER, node=DEFAULT_NODE)
 
 
 class TestAdaptersPrivate(TestAdaptersBase):
-    """Pass."""
-
     def test_private_get(self, apiobj):
-        """Pass."""
         adapters = apiobj._get()
         assert isinstance(adapters, dict)
         self.val_raw_adapters(adapters=adapters)
 
     def val_raw_adapters(self, adapters):
-        """Pass."""
         for name, instances in adapters.items():
             assert name.endswith("_adapter")
             assert isinstance(instances, list)
@@ -113,7 +102,6 @@ class TestAdaptersPrivate(TestAdaptersBase):
                 self.val_raw_adapter(name=name, instance=instance)
 
     def val_raw_adapter(self, name, instance):
-        """Pass."""
         node_id = instance.pop("node_id")
         assert isinstance(node_id, str) and node_id
 
@@ -162,7 +150,6 @@ class TestAdaptersPrivate(TestAdaptersBase):
             self.val_raw_client(name=name, client=client, instance_status=status)
 
     def val_raw_client(self, name, client, instance_status):
-        """Pass."""
         assert isinstance(client, dict)
 
         client_config = client.pop("client_config")
@@ -208,7 +195,6 @@ class TestAdaptersPrivate(TestAdaptersBase):
         assert not client
 
     def val_raw_schema(self, name, schema):
-        """Pass."""
         assert isinstance(schema, dict)
 
         items = schema.pop("items")
@@ -285,7 +271,6 @@ class TestAdaptersPrivate(TestAdaptersBase):
         assert not schema
 
     def test_private_file_upload_str(self, apiobj, adapter):
-        """Pass."""
         data = apiobj._file_upload(
             name_raw=adapter["name_raw"],
             node_id=adapter["node_id"],
@@ -298,7 +283,6 @@ class TestAdaptersPrivate(TestAdaptersBase):
         assert data["filename"]
 
     def test_private_file_upload_bytes(self, apiobj, adapter):
-        """Pass."""
         data = apiobj._file_upload(
             name_raw=adapter["name_raw"],
             node_id=adapter["node_id"],
@@ -311,10 +295,7 @@ class TestAdaptersPrivate(TestAdaptersBase):
         assert data["filename"]
 
     def test_private_config_update(self, apiobj, adapter):
-        """Pass."""
-        current = apiobj._config_get(
-            name_plugin=adapter["name_plugin"], name_config="AdapterBase"
-        )
+        current = apiobj._config_get(name_plugin=adapter["name_plugin"], name_config="AdapterBase")
         key = "user_last_fetched_threshold_hours"
         current_config = current["config"]
         config_update = copy.deepcopy(current_config)
@@ -327,10 +308,8 @@ class TestAdaptersPrivate(TestAdaptersBase):
             new_config=config_update,
         )
 
-        assert not set_response
-        updated = apiobj._config_get(
-            name_plugin=adapter["name_plugin"], name_config="AdapterBase"
-        )
+        assert set_response.get("config_name")
+        updated = apiobj._config_get(name_plugin=adapter["name_plugin"], name_config="AdapterBase")
         updated_config = updated["config"]
         assert updated_config[key] == set_value
         assert updated_config == config_update
@@ -343,14 +322,13 @@ class TestAdaptersPrivate(TestAdaptersBase):
             name_config="AdapterBase",
             new_config=reconfig_update,
         )
-        assert not reset_response
+        assert reset_response.get("config_name")
         post_reset = apiobj._config_get(
             name_plugin=adapter["name_plugin"], name_config="AdapterBase"
         )
         assert post_reset["config"] == current_config
 
     def test_private_config_get_generic(self, apiobj):
-        """Pass."""
         for meta in apiobj.get():
             data = apiobj._config_get(
                 name_plugin=meta["name_plugin"],
@@ -363,7 +341,6 @@ class TestAdaptersPrivate(TestAdaptersBase):
 
             schema = data.pop("schema")
             assert isinstance(schema, dict)
-            # XXX test schema!
 
             assert not data
 
@@ -383,7 +360,6 @@ class TestAdaptersPrivate(TestAdaptersBase):
             assert not schema
 
     def test_private_config_get_specific(self, apiobj):
-        """Pass."""
         for meta in apiobj.get():
             if not meta["schemas"]["specific_name"]:
                 continue
@@ -419,22 +395,17 @@ class TestAdaptersPrivate(TestAdaptersBase):
 
 
 class TestAdaptersPublic(TestAdaptersBase):
-    """Pass."""
-
     def test_get(self, apiobj):
-        """Pass."""
         adapters = apiobj.get()
         assert all(["schemas" in x for x in adapters])
         self.val_parsed_adapters(adapters=adapters)
 
     def val_parsed_adapters(self, adapters):
-        """Pass."""
         assert isinstance(adapters, list)
         for adapter in adapters:
             self.val_parsed_adapter(adapter=adapter)
 
     def val_parsed_adapter(self, adapter):
-        """Pass."""
         assert isinstance(adapter, dict)
 
         name = adapter.pop("name")
@@ -529,9 +500,13 @@ class TestAdaptersPublic(TestAdaptersBase):
         assert not adapter
 
     def val_parsed_cnx(
-        self, cnx, adapter_name, adapter_name_raw, adapter_node_id, adapter_node_name,
+        self,
+        cnx,
+        adapter_name,
+        adapter_name_raw,
+        adapter_node_id,
+        adapter_node_name,
     ):
-        """Pass."""
         assert isinstance(cnx, dict)
 
         cnx_adapter_name = cnx.pop("adapter_name")
@@ -571,28 +546,34 @@ class TestAdaptersPublic(TestAdaptersBase):
         assert not cnx
 
     def test_get_by_name(self, apiobj):
-        """Pass."""
         adapter = apiobj.get_by_name(name=CSV_ADAPTER, node=DEFAULT_NODE)
         assert "schemas" in adapter
         self.val_parsed_adapter(adapter=adapter)
 
     def test_get_by_name_bad_node(self, apiobj):
-        """Pass."""
         with pytest.raises(NotFoundError):
             apiobj.get_by_name(name=CSV_ADAPTER, node="badwolf")
 
     def test_get_by_name_bad_name(self, apiobj):
-        """Pass."""
         with pytest.raises(NotFoundError):
             apiobj.get_by_name(name="badwolf", node=DEFAULT_NODE)
 
     def test_config_get_bad_config_type(self, apiobj):
-        """Pass."""
         with pytest.raises(ApiError):
             apiobj.config_get(name=CSV_ADAPTER, node=DEFAULT_NODE, config_type="badwolf")
 
+    def test_config_get_discovery(self, apiobj):
+        data = apiobj.config_get(name="aws", node=DEFAULT_NODE, config_type="discovery")
+        assert isinstance(data, dict)
+        config = data.pop("config")
+        assert isinstance(config, dict) and config
+
+        schema = data.pop("schema")
+        assert isinstance(schema, dict) and schema
+
+        val_parsed_schema(schema=schema)
+
     def test_config_get_specific(self, apiobj):
-        """Pass."""
         data = apiobj.config_get(name="aws", node=DEFAULT_NODE, config_type="specific")
         assert isinstance(data, dict)
         config = data.pop("config")
@@ -604,10 +585,7 @@ class TestAdaptersPublic(TestAdaptersBase):
         val_parsed_schema(schema=schema)
 
     def test_config_get_generic(self, apiobj):
-        """Pass."""
-        data = apiobj.config_get(
-            name=CSV_ADAPTER, node=DEFAULT_NODE, config_type="generic"
-        )
+        data = apiobj.config_get(name=CSV_ADAPTER, node=DEFAULT_NODE, config_type="generic")
         assert isinstance(data, dict)
 
         config = data.pop("config")
@@ -619,7 +597,6 @@ class TestAdaptersPublic(TestAdaptersBase):
         val_parsed_schema(schema=schema)
 
     def test_file_upload_str(self, apiobj, adapter):
-        """Pass."""
         data = apiobj.file_upload(
             name=adapter["name"],
             node=adapter["node_name"],
@@ -632,19 +609,19 @@ class TestAdaptersPublic(TestAdaptersBase):
         assert data["filename"]
 
     def test_file_upload_path(self, apiobj, tmp_path):
-        """Pass."""
         test_path = tmp_path / CSV_FILENAME
         test_path.write_text(CSV_FILECONTENT_STR)
 
         data = apiobj.file_upload_path(
-            name=CSV_ADAPTER, node=DEFAULT_NODE, path=test_path,
+            name=CSV_ADAPTER,
+            node=DEFAULT_NODE,
+            path=test_path,
         )
         assert isinstance(data, dict)
         assert data["uuid"]
         assert data["filename"]
 
     def test_config_update_unknown(self, apiobj):
-        """Pass."""
         with pytest.raises(ConfigUnknown):
             apiobj.config_update(
                 name=CSV_ADAPTER,
@@ -654,14 +631,10 @@ class TestAdaptersPublic(TestAdaptersBase):
             )
 
     def test_config_update_unchanged(self, apiobj):
-        """Pass."""
         with pytest.raises(ConfigUnchanged):
-            apiobj.config_update(
-                name=CSV_ADAPTER, node=DEFAULT_NODE, config_type="generic"
-            )
+            apiobj.config_update(name=CSV_ADAPTER, node=DEFAULT_NODE, config_type="generic")
 
-    def test_config_update_generic_true(self, apiobj, adapter):
-        """Pass."""
+    def test_config_update_generic(self, apiobj, adapter):
         data = apiobj.config_refetch(adapter=adapter)
         current = data["config"]
         key = "user_last_fetched_threshold_hours"
