@@ -6,30 +6,26 @@ import json
 
 import pytest
 
-from .callbacks import Callbacks, load_test_data
+from ...utils import get_rows_exist
+from .callbacks import Callbacks
 
 
 class CallbacksJson(Callbacks):
-    """Pass."""
-
     @pytest.fixture(scope="class")
     def cbexport(self):
-        """Pass."""
         return "json"
 
     def test_row_as_is(self, cbexport, apiobj):
-        """Pass."""
         io_fd = io.StringIO()
+        original_rows = get_rows_exist(apiobj=apiobj, max_rows=5)
 
-        getargs = {"export_fd": io_fd}
-
-        cbobj = self.get_cbobj(apiobj=apiobj, cbexport=cbexport, getargs=getargs)
+        cbobj = self.get_cbobj(apiobj=apiobj, cbexport=cbexport, getargs={"export_fd": io_fd})
         cbobj.start()
 
         start_val = io_fd.getvalue().splitlines()[0]
         assert start_val == "["
 
-        for row in copy.deepcopy(apiobj.TEST_DATA["cb_assets"][:200]):
+        for row in copy.deepcopy(original_rows):
             row_id = row["internal_axon_id"]
             rows_ret = cbobj.process_row(row=copy.deepcopy(row))
             assert len(rows_ret) == 1
@@ -45,26 +41,29 @@ class CallbacksJson(Callbacks):
         assert "]" in stop_val
 
     def test_row_fully_loaded(self, cbexport, apiobj):
-        """Pass."""
         io_fd = io.StringIO()
+        original_rows = get_rows_exist(apiobj=apiobj, max_rows=5)
 
-        getargs = {
-            "export_fd": io_fd,
-            "field_excludes": ["adapters"],
-            "field_flatten": True,
-            "field_titles": True,
-            "field_join": True,
-            "field_null": True,
-            "report_adapters_missing": True,
-            "export_schema": True,
-        }
-        cbobj = self.get_cbobj(apiobj=apiobj, cbexport=cbexport, getargs=getargs)
+        cbobj = self.get_cbobj(
+            apiobj=apiobj,
+            cbexport=cbexport,
+            getargs={
+                "export_fd": io_fd,
+                "field_excludes": ["adapters"],
+                "field_flatten": True,
+                "field_titles": True,
+                "field_join": True,
+                "field_null": True,
+                "report_adapters_missing": True,
+                "export_schema": True,
+            },
+        )
         cbobj.start()
 
         start_val = io_fd.getvalue().splitlines()[0]
         assert start_val == "["
 
-        for row in copy.deepcopy(apiobj.TEST_DATA["cb_assets"][:20]):
+        for row in copy.deepcopy(original_rows):
             row_id = row["internal_axon_id"]
             rows_ret = cbobj.process_row(row=copy.deepcopy(row))
             assert len(rows_ret) == 1
@@ -83,18 +82,12 @@ class CallbacksJson(Callbacks):
 
 
 class TestDevicesCallbacksJson(CallbacksJson):
-    """Pass."""
-
     @pytest.fixture(scope="class")
     def apiobj(self, api_devices):
-        """Pass."""
-        return load_test_data(apiobj=api_devices)
+        return api_devices
 
 
 class TestUsersCallbacksJson(CallbacksJson):
-    """Pass."""
-
     @pytest.fixture(scope="class")
     def apiobj(self, api_users):
-        """Pass."""
-        return load_test_data(apiobj=api_users)
+        return api_users
