@@ -6,35 +6,19 @@ import requests
 from axonius_api_client.api import mixins
 from axonius_api_client.constants import MAX_PAGE_SIZE
 from axonius_api_client.exceptions import (
+    ApiError,
     JsonError,
     JsonInvalid,
     NotFoundError,
     ResponseNotOk,
+    ToolsError,
 )
-from axonius_api_client.tools import listify
 
 from ...meta import QUERIES
-
-
-def load_test_data(apiobj):
-    """Pass."""
-    apiobj.TEST_DATA = getattr(apiobj, "TEST_DATA", {})
-
-    if not apiobj.TEST_DATA.get("fields_map"):
-        apiobj.TEST_DATA["fields_map"] = fields_map = apiobj.fields.get()
-
-    if not apiobj.TEST_DATA.get("assets"):
-        apiobj.TEST_DATA["assets"] = apiobj.get(max_rows=4000, fields_map=fields_map)
-
-    if not apiobj.TEST_DATA.get("saved_queries"):
-        apiobj.TEST_DATA["saved_queries"] = apiobj.saved_query.get()
-
-    return apiobj
+from ...utils import check_asset, check_assets, get_field_vals, get_rows_exist
 
 
 class ModelMixinsBase:
-    """Pass."""
-
     def test_model_json(self, apiobj):
         """Test that JSON is returned when is_json=True."""
         response = apiobj.request(
@@ -71,9 +55,7 @@ class ModelMixinsBase:
     def test_model_json_error(self, apiobj):
         """Test exc thrown when json has error status."""
         with pytest.raises(JsonError):
-            apiobj.request(
-                path=apiobj.router.root + "/badwolf", method="get", error_status=False
-            )
+            apiobj.request(path=apiobj.router.root + "/badwolf", method="get", error_status=False)
 
     def test_model_no_json_error(self, apiobj):
         """Test exc thrown when status code != 200."""
@@ -96,64 +78,31 @@ class ModelMixinsBase:
         assert isinstance(response, str)
 
     def test_model_child(self, apiobj):
-        """Pass."""
         child = mixins.ChildMixins(parent=apiobj)
         assert str(apiobj) in str(child)
         assert repr(apiobj) in repr(child)
 
 
 class AssetsPrivate:
-    """Pass."""
-
-    # def test_private_get_page_stop_rows_stop(self, apiobj):
-    #     """Pass."""
-    #     state = {
-    #         "max_rows": None,
-    #         "rows_processed": 1,
-    #         "stop": True,
-    #         "stop_msg": "fakestop",
-    #         "max_pages": None,
-    #         "page_num": 1,
-    #     }
-    #     result = apiobj._get_page_stop_rows(row={}, rows=[{}], state=state, store={})
-    #     assert result is True
-
-    # def test_private_get_page_stop_fetch_stop(self, apiobj):
-    #     """Pass."""
-    #     state = {
-    #         "max_rows": None,
-    #         "rows_processed": 1,
-    #         "stop": True,
-    #         "stop_msg": "fakestop",
-    #         "max_pages": None,
-    #         "page_num": 1,
-    #     }
-    #     result = apiobj._get_page_stop_fetch(rows=[{}], state=state, store={})
-    #     assert result is True
-
     def test_private_get(self, apiobj):
-        """Pass."""
         data = apiobj._get(page_size=1)
         assert isinstance(data, dict)
         assert isinstance(data["assets"], list)
         assert len(data["assets"]) == 1
 
     def test_private_get_normal_query(self, apiobj):
-        """Pass."""
         data = apiobj._get(query=QUERIES["not_last_seen_day"], page_size=1)
         assert isinstance(data, dict)
         assert isinstance(data["assets"], list)
         assert len(data["assets"]) == 1
 
     def test_private_get_cursor(self, apiobj):
-        """Pass."""
         data = apiobj._get_cursor(page_size=1)
         assert isinstance(data, dict)
         assert isinstance(data["assets"], list)
         assert len(data["assets"]) == 1
 
     def test_private_get_cursor_query(self, apiobj):
-        """Pass."""
         query = QUERIES["not_last_seen_day"]
         data = apiobj._get_cursor(query=query, page_size=1)
         assert isinstance(data, dict)
@@ -161,26 +110,22 @@ class AssetsPrivate:
         assert len(data["assets"]) == 1
 
     def test_private_get_by_id(self, apiobj):
-        """Pass."""
-        asset = apiobj.TEST_DATA["assets"][0]
+        asset = apiobj.get(max_rows=1)[0]
         id = asset["internal_axon_id"]
         data = apiobj._get_by_id(id=id)
         assert isinstance(data, dict)
         assert data["internal_axon_id"] == id
 
     def test_private_count(self, apiobj):
-        """Pass."""
         data = apiobj._count()
         assert isinstance(data, int)
 
     def test_private_count_query(self, apiobj):
-        """Pass."""
         query = QUERIES["not_last_seen_day"]
         data = apiobj._count(query=query)
         assert isinstance(data, int)
 
     def test_private_build_query(self, apiobj):
-        """Pass."""
         pre_query = QUERIES["not_last_seen_day"]
         post_query = QUERIES["not_last_seen_day"]
 
@@ -208,28 +153,49 @@ class AssetsPrivate:
 
 
 class AssetsPublic:
-    """Pass."""
+    def test_sort(self, apiobj):
+        apiobj.get(max_rows=1, sort_field=apiobj.FIELD_MAIN)
+
+    def test_sort_bad(self, apiobj):
+        with pytest.raises(NotFoundError):
+            apiobj.get(max_rows=1, sort_field="badwolf")
+
+    def test_history_date(self, apiobj):
+        dates = apiobj.history_dates()
+        assert isinstance(dates, dict) and dates
+        for k, v in dates.items():
+            assert isinstance(k, str) and "-" in k
+            assert isinstance(v, str) and "-" in v and "T" in v
+
+    def test_validate_history_date(self, apiobj):
+        dates = apiobj.history_dates()
+        date = list(dates)[0]
+        dt = apiobj.validate_history_date(value=date)
+        assert dt == dates[date]
+
+    def test_validate_history_date_unknown_date(self, apiobj):
+        with pytest.raises(ApiError):
+            apiobj.validate_history_date(value="1999-09-09")
+
+    def test_validate_history_date_invalid_date(self, apiobj):
+        with pytest.raises(ToolsError):
+            apiobj.validate_history_date(value="xxx")
 
     def test_count(self, apiobj):
-        """Pass."""
         data = apiobj.count()
         assert isinstance(data, int)
 
     def test_count_query(self, apiobj):
-        """Pass."""
         query = QUERIES["not_last_seen_day"]
         data = apiobj.count(query=query)
         assert isinstance(data, int)
 
     def test_count_by_saved_query(self, apiobj):
-        """Pass."""
-        sq = apiobj.TEST_DATA["saved_queries"][0]
-        sq_name = sq["name"]
+        sq_name = apiobj.saved_query.get()[0]["name"]
         data = apiobj.count_by_saved_query(name=sq_name)
         assert isinstance(data, int)
 
     def test_get_cursor_no_generator_no(self, apiobj):
-        """Pass."""
         rows = apiobj.get(use_cursor=False, generator=False, max_rows=1)
 
         assert not rows.__class__.__name__ == "generator"
@@ -238,7 +204,6 @@ class AssetsPublic:
         assert len(rows) == 1
 
     def test_get_cursor_no_generator_yes(self, apiobj):
-        """Pass."""
         gen = apiobj.get(use_cursor=False, generator=True, max_rows=1)
 
         assert not isinstance(gen, list)
@@ -251,10 +216,6 @@ class AssetsPublic:
         assert len(rows) == 1
 
     def test_get_cursor_yes_generator_no(self, apiobj):
-        """Pass."""
-        if getattr(apiobj, "NO_CURSOR_OVERRIDE", False):
-            pytest.skip(f"{apiobj} has no cursor override")
-
         rows = apiobj.get(use_cursor=True, generator=False, max_rows=1)
 
         assert not rows.__class__.__name__ == "generator"
@@ -263,10 +224,6 @@ class AssetsPublic:
         assert len(rows) == 1
 
     def test_get_cursor_yes_generator_yes(self, apiobj):
-        """Pass."""
-        if getattr(apiobj, "NO_CURSOR_OVERRIDE", False):
-            pytest.skip(f"{apiobj} has no cursor override")
-
         gen = apiobj.get(use_cursor=True, generator=True, max_rows=1)
 
         assert gen.__class__.__name__ == "generator"
@@ -277,20 +234,17 @@ class AssetsPublic:
         assert len(rows) == 1
 
     def test_get_page_size_over_max(self, apiobj):
-        """Pass."""
         rows = apiobj.get(page_size=3000, max_pages=1)
         check_assets(rows)
         assert len(rows) <= MAX_PAGE_SIZE
 
     def test_get_maxpages(self, apiobj):
-        """Pass."""
         rows = apiobj.get(page_size=20, max_pages=1)
         check_assets(rows)
         assert len(rows) == 20
 
     def test_get_id(self, apiobj):
-        """Pass."""
-        asset = apiobj.TEST_DATA["assets"][0]
+        asset = apiobj.get(max_rows=1)[0]
         id = asset["internal_axon_id"]
 
         row = apiobj.get_by_id(id=id)
@@ -298,144 +252,119 @@ class AssetsPublic:
         assert row["internal_axon_id"] == id
 
     def test_get_id_error(self, apiobj):
-        """Pass."""
         with pytest.raises(NotFoundError):
             apiobj.get_by_id(id="badwolf")
 
     def test_get_by_saved_query(self, apiobj):
-        """Pass."""
-        sq = apiobj.TEST_DATA["saved_queries"][0]
+        sq = apiobj.saved_query.get()[0]
         sq_name = sq["name"]
         sq_fields = sq["view"]["fields"]
 
-        rows = apiobj.get_by_saved_query(
-            name=sq_name, max_rows=1, fields_map=apiobj.TEST_DATA["fields_map"],
-        )
+        rows = apiobj.get_by_saved_query(name=sq_name, max_rows=1)
         check_assets(rows)
 
         last_fields = apiobj._LAST_GET["fields"].split(",")
         assert sq_fields == last_fields
 
-    def test_get_by_value(self, apiobj):
-        """Pass."""
-        field = apiobj.TEST_DATA["field_main"]
-
-        values = get_field_values(rows=apiobj.TEST_DATA["assets"], field=field)
-        value = values[0]
-
-        rows = apiobj.get_by_value(
-            value=value, field=field, fields_map=apiobj.TEST_DATA["fields_map"],
+    def test_get_bys_value(self, apiobj):
+        self._all_get_by(
+            apiobj=apiobj,
+            method="value",
+            field="FIELD_MAIN",
+            use_field=apiobj.FIELD_MAIN,
         )
+
+    def _get_by_value(self, apiobj, method, field, not_flag=False, use_field=None):
+        field = getattr(apiobj, field)
+        row_with_val = get_rows_exist(apiobj=apiobj, fields=field)
+        value = get_field_vals(rows=row_with_val, field=field)[0]
+        method = getattr(apiobj, f"get_by_{method}")
+
+        method_args = {"value": value, "not_flag": not_flag, "max_rows": 5}
+        if use_field:
+            method_args["field"] = use_field
+
+        rows = method(**method_args)
+
         check_assets(rows)
-        assert len(rows) == 1
+        rows_values = get_field_vals(rows=rows, field=field)
 
-        rows_values = get_field_values(rows=rows, field=field)
-        assert value in rows_values
-
-    def test_get_by_value_not(self, apiobj):
-        """Pass."""
-        field = apiobj.TEST_DATA["field_main"]
-
-        values = get_field_values(rows=apiobj.TEST_DATA["assets"], field=field)
-        value = values[0]
-
-        rows = apiobj.get_by_value(
-            value=value,
-            field=field,
-            not_flag=True,
-            fields_map=apiobj.TEST_DATA["fields_map"],
-        )
-        check_assets(rows)
-
-        rows_values = get_field_values(rows=rows, field=field)
-        assert value not in rows_values
-
-    def test_get_by_values(self, apiobj):
-        """Pass."""
-        field = apiobj.TEST_DATA["field_main"]
-
-        values = get_field_values(rows=apiobj.TEST_DATA["assets"], field=field)
-        values = values[0:2]
-
-        rows = apiobj.get_by_values(
-            values=values, field=field, fields_map=apiobj.TEST_DATA["fields_map"],
-        )
-        check_assets(rows)
-
-        rows_values = get_field_values(rows=rows, field=field)
-        for value in values:
+        if not_flag:
+            assert value not in rows_values
+        else:
+            assert len(rows) == 1
             assert value in rows_values
 
-    def test_get_by_values_not(self, apiobj):
-        """Pass."""
-        field = apiobj.TEST_DATA["field_main"]
+    def _get_by_values(self, apiobj, method, field, not_flag=False, use_field=None):
+        field = getattr(apiobj, field)
+        rows_with_val = get_rows_exist(apiobj=apiobj, fields=field, max_rows=2)
+        values = get_field_vals(rows=rows_with_val, field=field)
+        method = getattr(apiobj, f"get_by_{method}s")
 
-        values = get_field_values(rows=apiobj.TEST_DATA["assets"], field=field)
-        values = values[0:2]
+        method_args = {"values": values, "not_flag": not_flag, "max_rows": 5}
+        if use_field:
+            method_args["field"] = use_field
 
-        rows = apiobj.get_by_values(
-            values=values,
-            field=field,
-            not_flag=True,
-            fields_map=apiobj.TEST_DATA["fields_map"],
-        )
+        rows = method(**method_args)
         check_assets(rows)
 
-        rows_values = get_field_values(rows=rows, field=field)
+        rows_values = get_field_vals(rows=rows, field=field)
         for value in values:
+            if not_flag:
+                assert value not in rows_values
+            else:
+                assert value in rows_values
+                assert len(rows) >= 1
+
+    def _get_by_value_re(self, apiobj, method, field, not_flag=False, use_field=None):
+        field = getattr(apiobj, field)
+        row_with_val = get_rows_exist(apiobj=apiobj, fields=field)
+        value = get_field_vals(rows=row_with_val, field=field)[0]
+        regex_value = value[0:5]
+
+        method = getattr(apiobj, f"get_by_{method}_regex")
+        method_args = {"value": regex_value, "not_flag": not_flag, "max_rows": 5}
+        if use_field:
+            method_args["field"] = use_field
+
+        rows = method(**method_args)
+        check_assets(rows)
+
+        rows_values = get_field_vals(rows=rows, field=field)
+        if not_flag:
             assert value not in rows_values
+        else:
+            assert value in rows_values
+            assert len(rows) >= 1
 
-    def test_get_by_value_regex(self, apiobj):
-        """Pass."""
-        field = apiobj.TEST_DATA["field_main"]
-
-        values = get_field_values(rows=apiobj.TEST_DATA["assets"], field=field)
-        value = values[0]
-        regex_value = value[0:5]
-
-        rows = apiobj.get_by_value_regex(
-            value=regex_value, field=field, fields_map=apiobj.TEST_DATA["fields_map"],
-        )
-        check_assets(rows)
-
-        rows_values = get_field_values(rows=rows, field=field)
-        assert value in rows_values
-
-    def test_get_by_value_regex_not(self, apiobj):
-        """Pass."""
-        field = apiobj.TEST_DATA["field_main"]
-
-        values = get_field_values(rows=apiobj.TEST_DATA["assets"], field=field)
-        value = values[0]
-        regex_value = value[0:5]
-
-        rows = apiobj.get_by_value_regex(
-            value=regex_value,
+    def _all_get_by(self, apiobj, method, field, use_field=None):
+        self._get_by_value(
+            apiobj=apiobj,
+            method=method,
             field=field,
-            not_flag=True,
-            fields_map=apiobj.TEST_DATA["fields_map"],
+            not_flag=False,
+            use_field=use_field,
+        )
+        self._get_by_value(
+            apiobj=apiobj, method=method, field=field, not_flag=True, use_field=use_field
+        )
+        self._get_by_values(
+            apiobj=apiobj,
+            method=method,
+            field=field,
+            not_flag=False,
+            use_field=use_field,
+        )
+        self._get_by_values(
+            apiobj=apiobj, method=method, field=field, not_flag=True, use_field=use_field
+        )
+        self._get_by_value_re(
+            apiobj=apiobj,
+            method=method,
+            field=field,
+            not_flag=False,
+            use_field=use_field,
+        )
+        self._get_by_value_re(
+            apiobj=apiobj, method=method, field=field, not_flag=True, use_field=use_field
         )
-        check_assets(rows)
-
-        rows_values = get_field_values(rows=rows, field=field)
-        assert value not in rows_values
-
-
-def get_field_values(rows, field):
-    """Pass."""
-    values = [x[field] for x in rows if x.get(field)]
-    values = [x for y in values for x in listify(y)]
-    return values
-
-
-def check_assets(rows):
-    """Pass."""
-    assert isinstance(rows, list)
-    for row in rows:
-        check_asset(row)
-
-
-def check_asset(row):
-    """Pass."""
-    assert isinstance(row, dict)
-    assert row["internal_axon_id"]
